@@ -9,9 +9,7 @@ write_bookdown_yml <- function(path, params) {
     rmd_subdir = "src",
     !!!params
   )
-  # TODO: quiet arg not passed
-  tmp <- utils::capture.output(ymlthis::use_bookdown_yml(bookdown_yml, path, quiet = TRUE))
-  # TODO: extra final line return
-  tmp_path <- gsub(".*'(.*)'.*", "\\1", tmp)
-  writeLines(utils::head(readLines(tmp_path), -1), tmp_path)
+  options(ymlthis.remove_blank_line = TRUE)
+  ymlthis::use_bookdown_yml(.yml = bookdown_yml, path = path, quiet = TRUE)
+  options(ymlthis.remove_blank_line = FALSE)
 }
